.. image:: https://travis-ci.org/Kalimaha/pytest-pact.svg?branch=master
    :target: https://travis-ci.org/Kalimaha/pytest-pact
.. image:: https://coveralls.io/repos/github/Kalimaha/pact-test/badge.svg?branch=development
    :target: https://coveralls.io/github/Kalimaha/pact-test?branch=development
.. image:: https://img.shields.io/badge/python-3.5-blue.svg
    :target: https://travis-ci.org/Kalimaha/pytest-pact
.. image:: https://img.shields.io/badge/python-3.6-blue.svg
    :target: https://travis-ci.org/Kalimaha/pytest-pact

Pact for PyTest
===============
Python implementation for Pact (http://pact.io/)

Setup
-----

.. code:: bash

  python setup.py install
